# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class CodingAttributionType(str, enum.Enum):
    CANDID = "CANDID"
    CUSTOMER = "CUSTOMER"
    TCN = "TCN"

    def visit(
        self,
        candid: typing.Callable[[], T_Result],
        customer: typing.Callable[[], T_Result],
        tcn: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is CodingAttributionType.CANDID:
            return candid()
        if self is CodingAttributionType.CUSTOMER:
            return customer()
        if self is CodingAttributionType.TCN:
            return tcn()
