# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .region_national import RegionNational
from .region_states import RegionStates


class Regions_States(RegionStates):
    type: typing_extensions.Literal["states"]

    class Config:
        frozen = True
        allow_population_by_field_name = True


class Regions_National(RegionNational):
    type: typing_extensions.Literal["national"]

    class Config:
        frozen = True
        allow_population_by_field_name = True


Regions = typing.Union[Regions_States, Regions_National]
