# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.too_many_requests_error_type import TooManyRequestsErrorType


class TooManyRequestsError(ApiError):
    def __init__(self, body: TooManyRequestsErrorType):
        super().__init__(status_code=429, body=body)
