# This file was auto-generated by Fern from our API Definition.

import typing

from ...environment import CandidApiEnvironment
from .resources.v_4.client import AsyncV4Client, V4Client


class EncountersClient:
    def __init__(
        self, *, environment: CandidApiEnvironment = CandidApiEnvironment.PRODUCTION, token: typing.Optional[str] = None
    ):
        self._environment = environment
        self._token = token
        self.v_4 = V4Client(environment=self._environment, token=self._token)


class AsyncEncountersClient:
    def __init__(
        self, *, environment: CandidApiEnvironment = CandidApiEnvironment.PRODUCTION, token: typing.Optional[str] = None
    ):
        self._environment = environment
        self._token = token
        self.v_4 = AsyncV4Client(environment=self._environment, token=self._token)
