# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EncounterAttachmentType(str, enum.Enum):
    DOCUMENTATION = "DOCUMENTATION"

    def visit(self, documentation: typing.Callable[[], T_Result]) -> T_Result:
        if self is EncounterAttachmentType.DOCUMENTATION:
            return documentation()
