# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from ...commons.types.claim_id import ClaimId
from ...commons.types.service_line_id import ServiceLineId
from ...commons.types.service_line_units import ServiceLineUnits
from .service_line_base_with_optionals import ServiceLineBaseWithOptionals


class ServiceLine(ServiceLineBaseWithOptionals):
    service_line_id: ServiceLineId
    procedure_code: str
    quantity: str
    units: ServiceLineUnits
    claim_id: ClaimId

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}
