# This file was auto-generated by Fern from our API Definition.

import enum


class CandidApiEnvironment(enum.Enum):
    PRODUCTION = "https://api.joincandidhealth.com"
    STAGING = "https://api-staging.joincandidhealth.com"
