# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions

from .credentialed_encounter_status_result import CredentialedEncounterStatusResult


class EncounterCredentialingStatusResult_Credentialed(CredentialedEncounterStatusResult):
    type: typing_extensions.Literal["credentialed"]

    class Config:
        frozen = True
        allow_population_by_field_name = True


class EncounterCredentialingStatusResult_NotCredentialed(pydantic.BaseModel):
    type: typing_extensions.Literal["not_credentialed"]

    class Config:
        frozen = True


EncounterCredentialingStatusResult = typing.Union[
    EncounterCredentialingStatusResult_Credentialed, EncounterCredentialingStatusResult_NotCredentialed
]
