# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .insurance_card_base import InsuranceCardBase
from .insurance_card_id import InsuranceCardId


class InsuranceCard(InsuranceCardBase):
    insurance_card_id: InsuranceCardId
    member_id: str
    payer_name: str
    payer_id: str
    rx_bin: typing.Optional[str]
    rx_pcn: typing.Optional[str]
    image_url_front: typing.Optional[str]
    image_url_back: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}
